summaryrefslogtreecommitdiff
path: root/src/arch/alpha/system.hh
diff options
context:
space:
mode:
authorNilay Vaish <nilay@cs.wisc.edu>2012-08-16 23:45:21 -0500
committerNilay Vaish <nilay@cs.wisc.edu>2012-08-16 23:45:21 -0500
commit649e37793776757d4076ce194fbe537b8d49e1db (patch)
tree2f3b8a82888096660d01fa661b94e53f054d79d1 /src/arch/alpha/system.hh
parent0b3897fc90901953e9d016466c37ab507f85023c (diff)
downloadgem5-649e37793776757d4076ce194fbe537b8d49e1db.tar.xz
Alpha System: override startup(), instead of loadState()
Alpha System was overriding loadState() function to setup some functional event. The system tried to read/write to memory before the Ruby memory had unserialized the state. With this patch, Alpha System overrides the startup() function, and sets up functional events in this function. This works because startup() is called after Ruby memory system has unserialized the memory state.
Diffstat (limited to 'src/arch/alpha/system.hh')
-rw-r--r--src/arch/alpha/system.hh4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/arch/alpha/system.hh b/src/arch/alpha/system.hh
index d832dfe77..024d8bb47 100644
--- a/src/arch/alpha/system.hh
+++ b/src/arch/alpha/system.hh
@@ -62,9 +62,9 @@ class AlphaSystem : public System
virtual void serialize(std::ostream &os);
virtual void unserialize(Checkpoint *cp, const std::string &section);
/** Override loadState to provide a path to call setupFuncEvents()
*/
- virtual void loadState(Checkpoint *cp);
+ virtual void startup();
/**
* Set the m5AlphaAccess pointer in the console
@@ -62,9 +62,9 @@ class AlphaSystem : public System
virtual void serialize(std::ostream &os);
virtual void unserialize(Checkpoint *cp, const std::string &section);
- /** Override loadState to provide a path to call setupFuncEvents()
+ /** Override startup() to provide a path to call setupFuncEvents()
*/